# Generated by Django 2.1.7 on 2019-03-07 11:03

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [("nuntius", "0009_verbose_names")]

    operations = [
        migrations.AlterModelOptions(
            name="campaign",
            options={"verbose_name": "Campaign", "verbose_name_plural": "Campaigns"},
        ),
        migrations.AlterModelOptions(
            name="campaignsentevent",
            options={
                "verbose_name": "Sent event",
                "verbose_name_plural": "Sent events",
            },
        ),
        migrations.AlterField(
            model_name="campaignsentevent",
            name="campaign",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                to="nuntius.Campaign",
                verbose_name="Campaign",
            ),
        ),
        migrations.AlterField(
            model_name="campaignsentevent",
            name="datetime",
            field=models.DateTimeField(auto_now_add=True, verbose_name="Sending time"),
        ),
        migrations.AlterField(
            model_name="campaignsentevent",
            name="email",
            field=models.EmailField(
                max_length=254, verbose_name="Email address at sending time"
            ),
        ),
    ]



# Generated by Django 2.1.7 on 2019-02-12 08:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("nuntius", "0006_subscriber_verbose_name")]

    operations = [
        migrations.AlterField(
            model_name="campaign",
            name="message_content_text",
            field=models.TextField(blank=True, verbose_name="Message content (text)"),
        )
    ]



# Generated by Django 2.1.7 on 2019-03-06 10:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("nuntius", "0007_message_content_text_blank")]

    operations = [
        migrations.AddField(
            model_name="campaign",
            name="first_sent",
            field=models.DateTimeField(blank=True, null=True),
        )
    ]



from django.db import transaction
from django.dispatch import receiver

from nuntius.actions import update_subscriber
from nuntius.models import CampaignSentEvent, CampaignSentStatusType, AbstractSubscriber

try:
    from anymail.signals import tracking, EventType

    @receiver(tracking, dispatch_uid="nuntius_anymail_tracking")
    def handle_anymail(sender, event, esp_name, **kwargs):
        actions = {
            EventType.SENT: (CampaignSentStatusType.OK, None),
            EventType.REJECTED: (CampaignSentStatusType.REJECTED, None),
            EventType.FAILED: (CampaignSentStatusType.ERROR, None),
            EventType.BOUNCED: (
                CampaignSentStatusType.BOUNCED,
                AbstractSubscriber.STATUS_BOUNCED,
            ),
            EventType.UNSUBSCRIBED: (
                CampaignSentStatusType.UNSUBSCRIBED,
                AbstractSubscriber.STATUS_UNSUBSCRIBED,
            ),
            EventType.COMPLAINED: (
                CampaignSentStatusType.COMPLAINED,
                AbstractSubscriber.STATUS_COMPLAINED,
            ),
        }

        try:
            with transaction.atomic():
                c = CampaignSentEvent.objects.select_for_update().get(
                    esp_message_id=event.message_id
                )
                if event.event_type in actions:
                    c.result = actions[event.event_type][0]
                if event.event_type == EventType.OPENED:
                    c.open_count = c.open_count + 1
                if event.event_type == EventType.CLICKED:
                    c.click_count = c.click_count + 1
                c.save()
        except CampaignSentEvent.DoesNotExist:
            pass

            if actions[event.event_type][1] is not None:
                update_subscriber(event.recipient, actions[event.event_type][1])


except ImportError:
    pass



# Generated by Django 2.0.7 on 2018-07-20 10:03

from django.db import migrations, models
import django.db.models.deletion
import nuntius.models


class Migration(migrations.Migration):

    dependencies = [("nuntius", "0002_add_mosaico")]

    operations = [
        migrations.AlterField(
            model_name="campaign",
            name="segment_content_type",
            field=models.ForeignKey(
                limit_choices_to=nuntius.models.segment_cts_q,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="contenttypes.ContentType",
            ),
        ),
        migrations.AlterField(
            model_name="campaign",
            name="segment_id",
            field=models.CharField(max_length=255, null=True),
        ),
    ]



# Generated by Django 2.1.7 on 2019-03-07 11:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("nuntius", "0010_verbose_names")]

    operations = [
        migrations.AddField(
            model_name="campaignsentevent",
            name="click_count",
            field=models.IntegerField(
                default=0, editable=False, verbose_name="Click count"
            ),
        ),
        migrations.AddField(
            model_name="campaignsentevent",
            name="open_count",
            field=models.IntegerField(
                default=0, editable=False, verbose_name="Open count"
            ),
        ),
    ]



# Generated by Django 2.1.7 on 2019-04-23 12:04

from django.db import migrations, models
import nuntius.models


class Migration(migrations.Migration):

    dependencies = [("nuntius", "0011_open_click_counts")]

    operations = [
        migrations.AddField(
            model_name="campaignsentevent",
            name="tracking_id",
            field=models.CharField(
                default=nuntius.models.CampaignSentEvent.generate_tracking_id,
                editable=False,
                max_length=12,
                null=True,
            ),
        )
    ]



from django.conf import settings
from django.contrib.contenttypes.models import ContentType


def update_subscriber(email, status):
    model = settings.NUNTIUS_SUBSCRIBER_MODEL
    model_class = ContentType.objects.get(
        app_label=model.split(".")[0], model=model.split(".")[1].lower()
    ).model_class()
    model_class.objects.set_subscriber_status(email, status)
